@@ -7,7 +7,7 @@ import (
 )
 
 const (
-	appVersion = "1.6.1"
+	appVersion = "1.9.0"
 )
 
 // versionCmd represents the version command.
@@ -15,7 +15,7 @@ var versionCmd = &cobra.Command{
 	Use:   "version",
 	Short: fmt.Sprintf("Display %s version and exit.\n", appName),
 	Long:  fmt.Sprintf("Display %s version and exit.\n", appName),
-	Run: func(cmd *cobra.Command, args []string) { //nolint:revive
+	Run: func(cmd *cobra.Command, args []string) {
 		fmt.Printf("%s v%s\n", appName, appVersion) //nolint:forbidigo
 	},
 }
