@@ -48,6 +48,7 @@ const (
 // ContainerRestoreDialog implements container restore dialog primitive.
 type ContainerRestoreDialog struct {
 	*tview.Box
+
 	layout          *tview.Flex
 	containers      *tview.DropDown
 	pods            *tview.DropDown
@@ -94,7 +95,6 @@ func NewContainerRestoreDialog() *ContainerRestoreDialog {
 	bgColor := style.DialogBgColor
 	ddUnselectedStyle := style.DropDownUnselected
 	ddselectedStyle := style.DropDownSelected
-	inputFieldBgColor := style.InputFieldBgColor
 
 	// containers
 	containersLabel := fmt.Sprintf("[:#%x:b]CONTAINER ID:[:-:-]", style.DialogBorderColor.Hex())
@@ -105,7 +105,8 @@ func NewContainerRestoreDialog() *ContainerRestoreDialog {
 	dialog.containers.SetBackgroundColor(bgColor)
 	dialog.containers.SetLabelColor(fgColor)
 	dialog.containers.SetListStyles(ddUnselectedStyle, ddselectedStyle)
-	dialog.containers.SetFieldBackgroundColor(inputFieldBgColor)
+	dialog.containers.SetFocusedStyle(style.DropDownFocused)
+	dialog.containers.SetFieldStyle(style.InputFieldStyle)
 	dialog.SetContainers(nil)
 	dialog.containers.SetCurrentOption(0)
 
@@ -117,34 +118,33 @@ func NewContainerRestoreDialog() *ContainerRestoreDialog {
 	dialog.pods.SetLabelColor(fgColor)
 	dialog.pods.SetLabelColor(fgColor)
 	dialog.pods.SetListStyles(ddUnselectedStyle, ddselectedStyle)
-	dialog.pods.SetFieldBackgroundColor(inputFieldBgColor)
+	dialog.pods.SetFocusedStyle(style.DropDownFocused)
+	dialog.pods.SetFieldStyle(style.InputFieldStyle)
 	dialog.SetPods(nil)
 	dialog.pods.SetCurrentOption(0)
 
 	// name
-	dialog.name.SetLabel("name:")
-	dialog.name.SetLabelWidth(cntRestoreDialogLabelWidth)
-	dialog.name.SetBackgroundColor(bgColor)
-	dialog.name.SetLabelColor(fgColor)
-	dialog.name.SetFieldBackgroundColor(inputFieldBgColor)
+	dialog.name.SetBackgroundColor(style.DialogBgColor)
+	dialog.name.SetLabel(utils.StringToInputLabel("name:", cntRestoreDialogLabelWidth))
+	dialog.name.SetFieldStyle(style.InputFieldStyle)
+	dialog.name.SetLabelStyle(style.InputLabelStyle)
 
 	// Publish ports
 	publishLabel := "publish:"
-	publishLabelWidth := len(publishLabel) + cntRestoreDialogPadding
+	publishLabelWidth := len(publishLabel) + cntRestoreDialogPadding + 1
 	publishPortsLabel := fmt.Sprintf("%*s ",
 		publishLabelWidth, publishLabel)
 
-	dialog.publishPorts.SetLabel(publishPortsLabel)
-	dialog.publishPorts.SetBackgroundColor(bgColor)
-	dialog.publishPorts.SetLabelColor(fgColor)
-	dialog.publishPorts.SetFieldBackgroundColor(inputFieldBgColor)
+	dialog.publishPorts.SetBackgroundColor(style.DialogBgColor)
+	dialog.publishPorts.SetLabel(utils.StringToInputLabel(publishPortsLabel, cntRestoreDialogLabelWidth))
+	dialog.publishPorts.SetFieldStyle(style.InputFieldStyle)
+	dialog.publishPorts.SetLabelStyle(style.InputLabelStyle)
 
 	// Import
-	dialog.importArchive.SetBackgroundColor(bgColor)
-	dialog.importArchive.SetLabelColor(fgColor)
-	dialog.importArchive.SetLabel("import:")
-	dialog.importArchive.SetLabelWidth(cntRestoreDialogLabelWidth)
-	dialog.importArchive.SetFieldBackgroundColor(inputFieldBgColor)
+	dialog.importArchive.SetBackgroundColor(style.DialogBgColor)
+	dialog.importArchive.SetLabel(utils.StringToInputLabel("import:", cntRestoreDialogLabelWidth))
+	dialog.importArchive.SetFieldStyle(style.InputFieldStyle)
+	dialog.importArchive.SetLabelStyle(style.InputLabelStyle)
 
 	// keep
 	dialog.keep.SetLabel("keep:")
@@ -152,7 +152,7 @@ func NewContainerRestoreDialog() *ContainerRestoreDialog {
 	dialog.keep.SetChecked(false)
 	dialog.keep.SetBackgroundColor(bgColor)
 	dialog.keep.SetLabelColor(fgColor)
-	dialog.keep.SetFieldBackgroundColor(inputFieldBgColor)
+	dialog.keep.SetFieldBackgroundColor(style.FieldBackgroundColor)
 
 	// ignoreStaticIP
 	ignoreStaticIPLabel := fmt.Sprintf("%*s ",
@@ -162,7 +162,7 @@ func NewContainerRestoreDialog() *ContainerRestoreDialog {
 	dialog.ignoreStaticIP.SetChecked(false)
 	dialog.ignoreStaticIP.SetBackgroundColor(bgColor)
 	dialog.ignoreStaticIP.SetLabelColor(fgColor)
-	dialog.ignoreStaticIP.SetFieldBackgroundColor(inputFieldBgColor)
+	dialog.ignoreStaticIP.SetFieldBackgroundColor(style.FieldBackgroundColor)
 
 	// ignoreStaticMAC
 	ignoreStaticMACLabel := fmt.Sprintf("%*s ",
@@ -172,7 +172,7 @@ func NewContainerRestoreDialog() *ContainerRestoreDialog {
 	dialog.ignoreStaticMAC.SetChecked(false)
 	dialog.ignoreStaticMAC.SetBackgroundColor(bgColor)
 	dialog.ignoreStaticMAC.SetLabelColor(fgColor)
-	dialog.ignoreStaticMAC.SetFieldBackgroundColor(inputFieldBgColor)
+	dialog.ignoreStaticMAC.SetFieldBackgroundColor(style.FieldBackgroundColor)
 
 	// fileLocks
 	fileLocksLabel := fmt.Sprintf("%*s ",
@@ -182,7 +182,7 @@ func NewContainerRestoreDialog() *ContainerRestoreDialog {
 	dialog.fileLocks.SetChecked(false)
 	dialog.fileLocks.SetBackgroundColor(bgColor)
 	dialog.fileLocks.SetLabelColor(fgColor)
-	dialog.fileLocks.SetFieldBackgroundColor(inputFieldBgColor)
+	dialog.fileLocks.SetFieldBackgroundColor(style.FieldBackgroundColor)
 
 	// printStats
 	dialog.printStats.SetLabel("print Stats: ")
@@ -190,7 +190,7 @@ func NewContainerRestoreDialog() *ContainerRestoreDialog {
 	dialog.printStats.SetChecked(false)
 	dialog.printStats.SetBackgroundColor(bgColor)
 	dialog.printStats.SetLabelColor(fgColor)
-	dialog.printStats.SetFieldBackgroundColor(inputFieldBgColor)
+	dialog.printStats.SetFieldBackgroundColor(style.FieldBackgroundColor)
 
 	// tcpEstablished
 	tcpEstablishedLabel := fmt.Sprintf("%*s ",
@@ -200,7 +200,7 @@ func NewContainerRestoreDialog() *ContainerRestoreDialog {
 	dialog.tcpEstablished.SetChecked(false)
 	dialog.tcpEstablished.SetBackgroundColor(bgColor)
 	dialog.tcpEstablished.SetLabelColor(fgColor)
-	dialog.tcpEstablished.SetFieldBackgroundColor(inputFieldBgColor)
+	dialog.tcpEstablished.SetFieldBackgroundColor(style.FieldBackgroundColor)
 
 	// ignoreVolumes
 	ignoreVolumesLabel := fmt.Sprintf("%*s ",
@@ -210,7 +210,7 @@ func NewContainerRestoreDialog() *ContainerRestoreDialog {
 	dialog.ignoreVolumes.SetChecked(false)
 	dialog.ignoreVolumes.SetBackgroundColor(bgColor)
 	dialog.ignoreVolumes.SetLabelColor(fgColor)
-	dialog.ignoreVolumes.SetFieldBackgroundColor(inputFieldBgColor)
+	dialog.ignoreVolumes.SetFieldBackgroundColor(style.FieldBackgroundColor)
 
 	// ignoreRootFS
 	ignoreRootFSLabel := fmt.Sprintf("%*s ",
@@ -220,7 +220,7 @@ func NewContainerRestoreDialog() *ContainerRestoreDialog {
 	dialog.ignoreRootFS.SetChecked(false)
 	dialog.ignoreRootFS.SetBackgroundColor(bgColor)
 	dialog.ignoreRootFS.SetLabelColor(fgColor)
-	dialog.ignoreRootFS.SetFieldBackgroundColor(inputFieldBgColor)
+	dialog.ignoreRootFS.SetFieldBackgroundColor(style.FieldBackgroundColor)
 
 	// form
 	dialog.form.AddButton("Cancel", nil)
@@ -434,9 +434,9 @@ func (d *ContainerRestoreDialog) Draw(screen tcell.Screen) {
 		return
 	}
 
-	d.Box.DrawForSubclass(screen, d)
+	d.DrawForSubclass(screen, d)
 
-	x, y, width, height := d.Box.GetInnerRect()
+	x, y, width, height := d.GetInnerRect()
 
 	d.layout.SetRect(x, y, width, height)
 	d.layout.Draw(screen)
@@ -462,36 +462,6 @@ func (d *ContainerRestoreDialog) SetCancelFunc(handler func()) *ContainerRestore
 	return d
 }
 
-func (d *ContainerRestoreDialog) setFocusElement() {
-	if d.focusElement < cntRestoreFormFocus {
-		d.focusElement++
-
-		return
-	}
-
-	d.focusElement = cntRestoreContainersFocus
-}
-
-func (d *ContainerRestoreDialog) getInnerPrimitives() []tview.Primitive {
-	// the item sort is important to be same as focus element number
-	return []tview.Primitive{
-		d.containers,
-		d.pods,
-		d.name,
-		d.publishPorts,
-		d.importArchive,
-		d.keep,
-		d.ignoreStaticIP,
-		d.ignoreStaticMAC,
-		d.fileLocks,
-		d.printStats,
-		d.tcpEstablished,
-		d.ignoreVolumes,
-		d.ignoreRootFS,
-		d.form,
-	}
-}
-
 // SetContainers sets containers dropdown options.
 func (d *ContainerRestoreDialog) SetContainers(cnts [][]string) {
 	emptyOptions := fmt.Sprintf("%*s", cntRestoreDialogSingleFieldWidth, " ")
@@ -556,3 +526,33 @@ func (d *ContainerRestoreDialog) GetRestoreOptions() containers.CntRestoreOption
 
 	return opts
 }
+
+func (d *ContainerRestoreDialog) setFocusElement() {
+	if d.focusElement < cntRestoreFormFocus {
+		d.focusElement++
+
+		return
+	}
+
+	d.focusElement = cntRestoreContainersFocus
+}
+
+func (d *ContainerRestoreDialog) getInnerPrimitives() []tview.Primitive {
+	// the item sort is important to be same as focus element number
+	return []tview.Primitive{
+		d.containers,
+		d.pods,
+		d.name,
+		d.publishPorts,
+		d.importArchive,
+		d.keep,
+		d.ignoreStaticIP,
+		d.ignoreStaticMAC,
+		d.fileLocks,
+		d.printStats,
+		d.tcpEstablished,
+		d.ignoreVolumes,
+		d.ignoreRootFS,
+		d.form,
+	}
+}
