@@ -42,6 +42,7 @@ const (
 // NetworkCreateDialog implements network create dialog.
 type NetworkCreateDialog struct {
 	*tview.Box
+
 	layout                    *tview.Flex
 	categoryLabels            []string
 	categories                *tview.TextView
@@ -93,7 +94,6 @@ func NewNetworkCreateDialog() *NetworkCreateDialog {
 
 	bgColor := style.DialogBgColor
 	fgColor := style.DialogFgColor
-	inputFieldBgColor := style.InputFieldBgColor
 	buttonBgColor := style.ButtonBgColor
 
 	netDialog.categories.SetDynamicColors(true).
@@ -105,19 +105,18 @@ func NewNetworkCreateDialog() *NetworkCreateDialog {
 
 	// basic information setup page
 	basicInfoPageLabelWidth := 12
+
 	// name field
-	netDialog.networkNameField.SetLabel("name:")
-	netDialog.networkNameField.SetLabelWidth(basicInfoPageLabelWidth)
 	netDialog.networkNameField.SetBackgroundColor(bgColor)
-	netDialog.networkNameField.SetLabelColor(fgColor)
-	netDialog.networkNameField.SetFieldBackgroundColor(inputFieldBgColor)
+	netDialog.networkNameField.SetLabel(utils.StringToInputLabel("name:", basicInfoPageLabelWidth))
+	netDialog.networkNameField.SetFieldStyle(style.InputFieldStyle)
+	netDialog.networkNameField.SetLabelStyle(style.InputLabelStyle)
 
 	// labels field
-	netDialog.networkLabelsField.SetLabel("labels:")
-	netDialog.networkLabelsField.SetLabelWidth(basicInfoPageLabelWidth)
 	netDialog.networkLabelsField.SetBackgroundColor(bgColor)
-	netDialog.networkLabelsField.SetLabelColor(fgColor)
-	netDialog.networkLabelsField.SetFieldBackgroundColor(inputFieldBgColor)
+	netDialog.networkLabelsField.SetLabel(utils.StringToInputLabel("labels:", basicInfoPageLabelWidth))
+	netDialog.networkLabelsField.SetFieldStyle(style.InputFieldStyle)
+	netDialog.networkLabelsField.SetLabelStyle(style.InputLabelStyle)
 
 	// internal check box
 	netDialog.networkInternalCheckBox.SetLabel("internal")
@@ -125,21 +124,19 @@ func NewNetworkCreateDialog() *NetworkCreateDialog {
 	netDialog.networkInternalCheckBox.SetChecked(false)
 	netDialog.networkInternalCheckBox.SetBackgroundColor(bgColor)
 	netDialog.networkInternalCheckBox.SetLabelColor(fgColor)
-	netDialog.networkInternalCheckBox.SetFieldBackgroundColor(inputFieldBgColor)
+	netDialog.networkInternalCheckBox.SetFieldBackgroundColor(style.FieldBackgroundColor)
 
 	// drivers
-	netDialog.networkDriverField.SetLabel("drivers:")
-	netDialog.networkDriverField.SetLabelWidth(basicInfoPageLabelWidth)
 	netDialog.networkDriverField.SetBackgroundColor(bgColor)
-	netDialog.networkDriverField.SetLabelColor(fgColor)
-	netDialog.networkDriverField.SetFieldBackgroundColor(inputFieldBgColor)
+	netDialog.networkDriverField.SetLabel(utils.StringToInputLabel("drivers:", basicInfoPageLabelWidth))
+	netDialog.networkDriverField.SetFieldStyle(style.InputFieldStyle)
+	netDialog.networkDriverField.SetLabelStyle(style.InputLabelStyle)
 
 	// drivers options
-	netDialog.networkDriverOptionsField.SetLabel("options:")
-	netDialog.networkDriverOptionsField.SetLabelWidth(basicInfoPageLabelWidth)
 	netDialog.networkDriverOptionsField.SetBackgroundColor(bgColor)
-	netDialog.networkDriverOptionsField.SetLabelColor(fgColor)
-	netDialog.networkDriverOptionsField.SetFieldBackgroundColor(inputFieldBgColor)
+	netDialog.networkDriverOptionsField.SetLabel(utils.StringToInputLabel("options:", basicInfoPageLabelWidth))
+	netDialog.networkDriverOptionsField.SetFieldStyle(style.InputFieldStyle)
+	netDialog.networkDriverOptionsField.SetLabelStyle(style.InputLabelStyle)
 
 	// ip settings page
 	ipSettingsPageLabelWidth := 12
@@ -149,28 +146,25 @@ func NewNetworkCreateDialog() *NetworkCreateDialog {
 	netDialog.networkIpv6CheckBox.SetChecked(false)
 	netDialog.networkIpv6CheckBox.SetBackgroundColor(bgColor)
 	netDialog.networkIpv6CheckBox.SetLabelColor(tcell.ColorWhite)
-	netDialog.networkIpv6CheckBox.SetFieldBackgroundColor(inputFieldBgColor)
+	netDialog.networkIpv6CheckBox.SetFieldBackgroundColor(style.FieldBackgroundColor)
 
 	// gateway
-	netDialog.networkGatewayField.SetLabel("gateway:")
-	netDialog.networkGatewayField.SetLabelWidth(basicInfoPageLabelWidth)
 	netDialog.networkGatewayField.SetBackgroundColor(bgColor)
-	netDialog.networkGatewayField.SetLabelColor(tcell.ColorWhite)
-	netDialog.networkGatewayField.SetFieldBackgroundColor(inputFieldBgColor)
+	netDialog.networkGatewayField.SetLabel(utils.StringToInputLabel("gateway:", basicInfoPageLabelWidth))
+	netDialog.networkGatewayField.SetFieldStyle(style.InputFieldStyle)
+	netDialog.networkGatewayField.SetLabelStyle(style.InputLabelStyle)
 
 	// ip range
-	netDialog.networkIPRangeField.SetLabel("ip range:")
-	netDialog.networkIPRangeField.SetLabelWidth(basicInfoPageLabelWidth)
 	netDialog.networkIPRangeField.SetBackgroundColor(bgColor)
-	netDialog.networkIPRangeField.SetLabelColor(tcell.ColorWhite)
-	netDialog.networkIPRangeField.SetFieldBackgroundColor(inputFieldBgColor)
+	netDialog.networkIPRangeField.SetLabel(utils.StringToInputLabel("ip range:", basicInfoPageLabelWidth))
+	netDialog.networkIPRangeField.SetFieldStyle(style.InputFieldStyle)
+	netDialog.networkIPRangeField.SetLabelStyle(style.InputLabelStyle)
 
 	// subnet
-	netDialog.networkSubnetField.SetLabel("subnet:")
-	netDialog.networkSubnetField.SetLabelWidth(basicInfoPageLabelWidth)
 	netDialog.networkSubnetField.SetBackgroundColor(bgColor)
-	netDialog.networkSubnetField.SetLabelColor(tcell.ColorWhite)
-	netDialog.networkSubnetField.SetFieldBackgroundColor(inputFieldBgColor)
+	netDialog.networkSubnetField.SetLabel(utils.StringToInputLabel("subnet:", basicInfoPageLabelWidth))
+	netDialog.networkSubnetField.SetFieldStyle(style.InputFieldStyle)
+	netDialog.networkSubnetField.SetLabelStyle(style.InputLabelStyle)
 
 	// dns check box
 	netDialog.networkDisableDNSCheckBox.SetLabel("disable DNS")
@@ -178,7 +172,7 @@ func NewNetworkCreateDialog() *NetworkCreateDialog {
 	netDialog.networkDisableDNSCheckBox.SetChecked(false)
 	netDialog.networkDisableDNSCheckBox.SetBackgroundColor(bgColor)
 	netDialog.networkDisableDNSCheckBox.SetLabelColor(tcell.ColorWhite)
-	netDialog.networkDisableDNSCheckBox.SetFieldBackgroundColor(inputFieldBgColor)
+	netDialog.networkDisableDNSCheckBox.SetFieldBackgroundColor(style.FieldBackgroundColor)
 
 	// category pages
 	netDialog.categoryPages.SetBackgroundColor(bgColor)
@@ -204,49 +198,6 @@ func NewNetworkCreateDialog() *NetworkCreateDialog {
 	return &netDialog
 }
 
-func (d *NetworkCreateDialog) setupLayout() {
-	bgColor := style.DialogBgColor
-
-	// basic info page
-	d.basicInfoPage.SetDirection(tview.FlexRow)
-	d.basicInfoPage.AddItem(d.networkNameField, 1, 0, true)
-	d.basicInfoPage.AddItem(utils.EmptyBoxSpace(bgColor), 1, 0, true)
-	d.basicInfoPage.AddItem(d.networkLabelsField, 1, 0, true)
-	d.basicInfoPage.AddItem(utils.EmptyBoxSpace(bgColor), 1, 0, true)
-	d.basicInfoPage.AddItem(d.networkInternalCheckBox, 1, 0, true)
-	d.basicInfoPage.AddItem(utils.EmptyBoxSpace(bgColor), 1, 0, true)
-	d.basicInfoPage.AddItem(d.networkDriverField, 1, 0, true)
-	d.basicInfoPage.AddItem(utils.EmptyBoxSpace(bgColor), 1, 0, true)
-	d.basicInfoPage.AddItem(d.networkDriverOptionsField, 1, 0, true)
-	d.basicInfoPage.SetBackgroundColor(bgColor)
-
-	// ip settings page
-	d.ipSettingsPage.SetDirection(tview.FlexRow)
-	d.ipSettingsPage.AddItem(d.networkIpv6CheckBox, 1, 0, true)
-	d.ipSettingsPage.AddItem(utils.EmptyBoxSpace(bgColor), 1, 0, true)
-	d.ipSettingsPage.AddItem(d.networkGatewayField, 1, 0, true)
-	d.ipSettingsPage.AddItem(utils.EmptyBoxSpace(bgColor), 1, 0, true)
-	d.ipSettingsPage.AddItem(d.networkIPRangeField, 1, 0, true)
-	d.ipSettingsPage.AddItem(utils.EmptyBoxSpace(bgColor), 1, 0, true)
-	d.ipSettingsPage.AddItem(d.networkSubnetField, 1, 0, true)
-	d.ipSettingsPage.AddItem(utils.EmptyBoxSpace(bgColor), 1, 0, true)
-	d.ipSettingsPage.AddItem(d.networkDisableDNSCheckBox, 1, 0, true)
-	d.ipSettingsPage.SetBackgroundColor(bgColor)
-
-	// adding category pages
-	d.categoryPages.AddPage(d.categoryLabels[basicInfoPageIndex], d.basicInfoPage, true, true)
-	d.categoryPages.AddPage(d.categoryLabels[ipSettingsPageIndex], d.ipSettingsPage, true, true)
-
-	// add it to layout.
-	_, layoutWidth := utils.AlignStringListWidth(d.categoryLabels)
-	layout := tview.NewFlex().SetDirection(tview.FlexColumn)
-	layout.AddItem(d.categories, layoutWidth+6, 0, true) //nolint:mnd
-	layout.AddItem(d.categoryPages, 0, 1, true)
-	layout.SetBackgroundColor(bgColor)
-
-	d.layout.AddItem(layout, 0, 1, true)
-}
-
 // Display displays this primitive.
 func (d *NetworkCreateDialog) Display() {
 	d.display = true
@@ -434,8 +385,8 @@ func (d *NetworkCreateDialog) Draw(screen tcell.Screen) {
 		return
 	}
 
-	d.Box.DrawForSubclass(screen, d)
-	x, y, width, height := d.Box.GetInnerRect()
+	d.DrawForSubclass(screen, d)
+	x, y, width, height := d.GetInnerRect()
 
 	d.layout.SetRect(x, y, width, height)
 	d.layout.Draw(screen)
@@ -461,6 +412,115 @@ func (d *NetworkCreateDialog) SetCreateFunc(handler func()) *NetworkCreateDialog
 	return d
 }
 
+// NetworkCreateOptions returns new network options.
+func (d *NetworkCreateDialog) NetworkCreateOptions() networks.CreateOptions { //nolint:cyclop
+	var (
+		labels   = make(map[string]string)
+		options  = make(map[string]string)
+		subnets  []string
+		gateways []string
+		ipranges []string
+	)
+
+	for _, label := range strings.Split(d.networkLabelsField.GetText(), " ") {
+		if label != "" {
+			split := strings.Split(label, "=")
+			if len(split) == 2 { //nolint:mnd
+				key := split[0]
+				value := split[1]
+
+				if key != "" && value != "" {
+					labels[key] = value
+				}
+			}
+		}
+	}
+
+	for _, option := range strings.Split(d.networkDriverOptionsField.GetText(), " ") {
+		if option != "" {
+			split := strings.Split(option, "=")
+			if len(split) == 2 { //nolint:mnd
+				key := split[0]
+				value := split[1]
+
+				if key != "" && value != "" {
+					options[key] = value
+				}
+			}
+		}
+	}
+
+	if strings.Trim(d.networkGatewayField.GetText(), " ") != "" {
+		gateways = strings.Split(d.networkGatewayField.GetText(), " ")
+	}
+
+	if strings.Trim(d.networkSubnetField.GetText(), " ") != "" {
+		subnets = strings.Split(d.networkSubnetField.GetText(), " ")
+	}
+
+	if strings.Trim(d.networkIPRangeField.GetText(), " ") != "" {
+		ipranges = strings.Split(d.networkIPRangeField.GetText(), " ")
+	}
+
+	opts := networks.CreateOptions{
+		Name:           strings.TrimSpace(d.networkNameField.GetText()),
+		Labels:         labels,
+		Internal:       d.networkInternalCheckBox.IsChecked(),
+		Drivers:        strings.TrimSpace(d.networkDriverField.GetText()),
+		DriversOptions: options,
+		IPv6:           d.networkIpv6CheckBox.IsChecked(),
+		Gateways:       gateways,
+		Subnets:        subnets,
+		IPRanges:       ipranges,
+		DisableDNS:     d.networkDisableDNSCheckBox.IsChecked(),
+	}
+
+	return opts
+}
+
+func (d *NetworkCreateDialog) setupLayout() {
+	bgColor := style.DialogBgColor
+
+	// basic info page
+	d.basicInfoPage.SetDirection(tview.FlexRow)
+	d.basicInfoPage.AddItem(d.networkNameField, 1, 0, true)
+	d.basicInfoPage.AddItem(utils.EmptyBoxSpace(bgColor), 1, 0, true)
+	d.basicInfoPage.AddItem(d.networkLabelsField, 1, 0, true)
+	d.basicInfoPage.AddItem(utils.EmptyBoxSpace(bgColor), 1, 0, true)
+	d.basicInfoPage.AddItem(d.networkInternalCheckBox, 1, 0, true)
+	d.basicInfoPage.AddItem(utils.EmptyBoxSpace(bgColor), 1, 0, true)
+	d.basicInfoPage.AddItem(d.networkDriverField, 1, 0, true)
+	d.basicInfoPage.AddItem(utils.EmptyBoxSpace(bgColor), 1, 0, true)
+	d.basicInfoPage.AddItem(d.networkDriverOptionsField, 1, 0, true)
+	d.basicInfoPage.SetBackgroundColor(bgColor)
+
+	// ip settings page
+	d.ipSettingsPage.SetDirection(tview.FlexRow)
+	d.ipSettingsPage.AddItem(d.networkIpv6CheckBox, 1, 0, true)
+	d.ipSettingsPage.AddItem(utils.EmptyBoxSpace(bgColor), 1, 0, true)
+	d.ipSettingsPage.AddItem(d.networkGatewayField, 1, 0, true)
+	d.ipSettingsPage.AddItem(utils.EmptyBoxSpace(bgColor), 1, 0, true)
+	d.ipSettingsPage.AddItem(d.networkIPRangeField, 1, 0, true)
+	d.ipSettingsPage.AddItem(utils.EmptyBoxSpace(bgColor), 1, 0, true)
+	d.ipSettingsPage.AddItem(d.networkSubnetField, 1, 0, true)
+	d.ipSettingsPage.AddItem(utils.EmptyBoxSpace(bgColor), 1, 0, true)
+	d.ipSettingsPage.AddItem(d.networkDisableDNSCheckBox, 1, 0, true)
+	d.ipSettingsPage.SetBackgroundColor(bgColor)
+
+	// adding category pages
+	d.categoryPages.AddPage(d.categoryLabels[basicInfoPageIndex], d.basicInfoPage, true, true)
+	d.categoryPages.AddPage(d.categoryLabels[ipSettingsPageIndex], d.ipSettingsPage, true, true)
+
+	// add it to layout.
+	_, layoutWidth := utils.AlignStringListWidth(d.categoryLabels)
+	layout := tview.NewFlex().SetDirection(tview.FlexColumn)
+	layout.AddItem(d.categories, layoutWidth+6, 0, true) //nolint:mnd
+	layout.AddItem(d.categoryPages, 0, 1, true)
+	layout.SetBackgroundColor(bgColor)
+
+	d.layout.AddItem(layout, 0, 1, true)
+}
+
 func (d *NetworkCreateDialog) setActiveCategory(index int) {
 	fgColor := style.DialogFgColor
 	bgColor := style.ButtonBgColor
@@ -584,69 +644,3 @@ func (d *NetworkCreateDialog) setIPSettingsPageNextFocus() {
 
 	d.focusElement = formFocus
 }
-
-// NetworkCreateOptions returns new network options.
-func (d *NetworkCreateDialog) NetworkCreateOptions() networks.CreateOptions { //nolint:cyclop
-	var (
-		labels   = make(map[string]string)
-		options  = make(map[string]string)
-		subnets  []string
-		gateways []string
-		ipranges []string
-	)
-
-	for _, label := range strings.Split(d.networkLabelsField.GetText(), " ") {
-		if label != "" {
-			split := strings.Split(label, "=")
-			if len(split) == 2 { //nolint:mnd
-				key := split[0]
-				value := split[1]
-
-				if key != "" && value != "" {
-					labels[key] = value
-				}
-			}
-		}
-	}
-
-	for _, option := range strings.Split(d.networkDriverOptionsField.GetText(), " ") {
-		if option != "" {
-			split := strings.Split(option, "=")
-			if len(split) == 2 { //nolint:mnd
-				key := split[0]
-				value := split[1]
-
-				if key != "" && value != "" {
-					options[key] = value
-				}
-			}
-		}
-	}
-
-	if strings.Trim(d.networkGatewayField.GetText(), " ") != "" {
-		gateways = strings.Split(d.networkGatewayField.GetText(), " ")
-	}
-
-	if strings.Trim(d.networkSubnetField.GetText(), " ") != "" {
-		subnets = strings.Split(d.networkSubnetField.GetText(), " ")
-	}
-
-	if strings.Trim(d.networkIPRangeField.GetText(), " ") != "" {
-		ipranges = strings.Split(d.networkIPRangeField.GetText(), " ")
-	}
-
-	opts := networks.CreateOptions{
-		Name:           strings.TrimSpace(d.networkNameField.GetText()),
-		Labels:         labels,
-		Internal:       d.networkInternalCheckBox.IsChecked(),
-		Drivers:        strings.TrimSpace(d.networkDriverField.GetText()),
-		DriversOptions: options,
-		IPv6:           d.networkIpv6CheckBox.IsChecked(),
-		Gateways:       gateways,
-		Subnets:        subnets,
-		IPRanges:       ipranges,
-		DisableDNS:     d.networkDisableDNSCheckBox.IsChecked(),
-	}
-
-	return opts
-}
