@@ -4,21 +4,11 @@ import (
 	"fmt"
 	"strings"
 
-	"github.com/containers/podman-tui/pdcs/networks"
 	"github.com/containers/podman-tui/ui/style"
 	"github.com/rivo/tview"
-	"github.com/rs/zerolog/log"
 )
 
-// UpdateData retrieves networks list data.
-func (nets *Networks) UpdateData() {
-	netList, err := networks.List()
-	if err != nil {
-		log.Error().Msgf("view: networks update %v", err)
-		nets.errorDialog.SetText(fmt.Sprintf("%v", err))
-		nets.errorDialog.Display()
-	}
-
+func (nets *Networks) refresh(_ int) {
 	nets.table.Clear()
 
 	expand := 1
@@ -34,54 +24,38 @@ func (nets *Networks) UpdateData() {
 													SetSelectable(false))
 	}
 
+	currentSelectedRow, _ := nets.table.GetSelection()
 	rowIndex := 1
+	netList := nets.getData()
 
 	nets.table.SetTitle(fmt.Sprintf("[::b]%s[%d]", strings.ToUpper(nets.title), len(netList)))
 
-	for i := range netList {
-		netID := netList[i][0]
-		netName := netList[i][1]
-		netDriver := netList[i][2]
-
+	for _, net := range netList {
 		// name column
 		nets.table.SetCell(rowIndex, viewNetworkNameColIndex,
-			tview.NewTableCell(netID[:12]).
+			tview.NewTableCell(net.ID[:12]).
 				SetExpansion(expand).
 				SetAlign(alignment))
 
 		// version column
 		nets.table.SetCell(rowIndex, viewNetworkVersionColIndex,
-			tview.NewTableCell(netName).
+			tview.NewTableCell(net.Name).
 				SetExpansion(expand).
 				SetAlign(alignment))
 
 		// plugins at column
 		nets.table.SetCell(rowIndex, viewNetworkPluginColIndex,
-			tview.NewTableCell(netDriver).
+			tview.NewTableCell(net.Driver).
 				SetExpansion(expand).
 				SetAlign(alignment))
 
 		rowIndex++
 	}
-}
 
-// ClearData clears table data.
-func (nets *Networks) ClearData() {
-	nets.table.Clear()
-
-	expand := 1
-	fgColor := style.PageHeaderFgColor
-	bgColor := style.PageHeaderBgColor
-
-	for i := range nets.headers {
-		nets.table.SetCell(0, i,
-			tview.NewTableCell(fmt.Sprintf("[::b]%s", strings.ToUpper(nets.headers[i]))). //nolint:perfsprint
-													SetExpansion(expand).
-													SetBackgroundColor(bgColor).
-													SetTextColor(fgColor).
-													SetAlign(tview.AlignLeft).
-													SetSelectable(false))
+	if currentSelectedRow > len(netList) {
+		currentSelectedRow--
+		if currentSelectedRow >= 0 {
+			nets.table.Select(currentSelectedRow, -1)
+		}
 	}
-
-	nets.table.SetTitle(fmt.Sprintf("[::b]%s[0]", strings.ToUpper(nets.title)))
 }
